/*
Copyright (C) 2009 -  Claudio Salvadori 
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

/**
 *\file XML_enum.h
 *
 *\date  Created on: 24-apr-2009
 *\author  Author: Claudio Salvadori
 *\brief Enumeration for Xml file parsing and analysis
 */

#ifndef _XML_ENUM_H_
#define _XML_ENUM_H_

#include "DAQ_enum.h"

/**
*\brief Enumeration of possible result of xml parsing method.
*/
enum xml_parser_ret_value{
	R_XML_OK		=	0,	/**<Ok*/
	R_XML_INIT_ERR		=	1,	/**<Error in parser init*/
	R_XML_INIT_H_ERR	=	2,	/**<Error in error handler init*/
	R_XML_PARSER_ERR	=	3,	/**<Error in parsing*/
	R_XML_P_FILE_ERR	=	4,  	/**<Syntax error in file.xml*/
	R_XML_P_DOM_ERR		=	5,  	/**<Error in DOM parsing*/
	R_XML_P_UN_ERR		=	6,  	/**<Unexpected exception during parsing*/
};

/**
*\brief Enumeration of possible result CXml class method.
*/
enum x_ret{
	X_RET_OK		=	0,	/**<Ok*/
	X_INIT_ERR		=	1,	/**<Error in parser init*/
	X_PARSE_ERR		=	2,	/**<Error in parsing*/
	X_XML_PARSER_ERR	=	3,	/**<Error in parsing*/
	X_XML_P_FILE_ERR	=	4,  	/**<Syntax error in file.xml*/
	X_XML_P_DOM_ERR		=	5, 	/**<Error in DOM parsing*/
	X_XML_P_UN_ERR		=	6,  	/**<Unexpected exception during parsing*/
	X_P_STYLE_ERR		=	7,  	/**<Style error*/
	X_P_TITLE_ERR		=	8, 	/**<Title error*/
	X_P_STREAM_ERR		=	9,	/**<Stream node searching error*/
	X_P_STREAM_T_ERR	=	10,	/**<Stream type error*/
	X_P_STREAM_N_ERR	=	11,	/**<Stream name error*/
	X_P_STREAM_FT_ERR	=	12, 	/**<Stream file type error*/
	X_P_STREAM_C_ERR	=	13, 	/**<Stream channel/port error*/
	X_P_PKT_ERR		=	14,	/**<Packet node searching error*/
	X_P_PKT_S_ERR		=	15, 	/**<Packet size error*/
	X_P_DTA_ERR		=	16, 	/**<Data node searching error*/
	X_P_DTA_N_ERR		=	17,	/**<Data name error*/
	X_P_DTA_P_ERR		=	18, 	/**<Data position error*/
	X_P_DTA_S_ERR		=	19, 	/**<Data size error*/
	X_P_DTA_T_ERR		=	20, 	/**<Data type error*/
	X_GENERIC_ERR		=	21,	/**<Generic error*/
	X_VAL_MDATA_ERR		=	22,	/**<Validate metadata error*/
	X_P_S_STREAM_ERR	=	23,	/**<Serial stream node searching error*/
	X_P_BAUD_RATE_ERR	=	24, 	/**<Baud rate error*/
	X_P_DATA_BITS_ERR	=	25, 	/**<Data bits error*/
	X_P_PARITY_ERR		=	26,	/**<Parity bits error*/
	X_P_STOP_ERR		=	27,	/**<Stop bits error*/
	X_P_HAND_ERR		=	28,	/**<Handshaking node searching error*/
	X_P_HAND_P_ERR		=	29,	/**<Handshaking packet node searching error*/
	X_P_H_SEND_ERR		= 	30,	/**<Send packet error*/
	X_P_O_STREAM_ERR	= 	31,	/**<Option stream node searching error*/
	X_P_O_TYPE_ERR		= 	32,	/**<Option type error*/
	X_P_O_START_ERR		= 	33,	/**<Start character error*/
	X_P_O_END_ERR		= 	34,	/**<End character error*/
	X_P_O_ESC_ERR		= 	35,	/**<Escape character error*/
	X_P_H_ACK_ERR		= 	36,	/**<Ack packet error*/
	X_P_H_NACK_ERR		= 	37,	/**<Nack packet error*/
	X_P_H_STYLE_ERR		=	38,	/**<Handshaking style error*/
};

/**
*\brief Enumeration of possible XML file style.
*/
enum x_style{
	ST_1			=	1,	/**<Style = 1 without handshaking protocol*/
	ST_2			=	2,	/**<Style = 2 with handshaking protocol*/
};

/**
*\brief Enumeration of possible type to write character
*/
enum x_msg_type{
	X_S_T_HEX			=	1,	/**<Hexadecimal*/
	X_S_T_CHAR			=	2,	/**<Character*/
};

#endif
	
